#
# spec file for package python-django-ckeditor
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-ckeditor
Version:        6.7.2
Release:        1.2
Summary:        Django admin CKEditor integration
License:        BSD-3-Clause
URL:            https://github.com/django-ckeditor/django-ckeditor
Source:         https://files.pythonhosted.org/packages/source/d/django_ckeditor/django_ckeditor-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/ckeditor/ckeditor4/commit/8ed1a3c93d0ae5f49f4ecff5738ab8a2972194cb https://github.com/ckeditor/ckeditor4/security/advisories/GHSA-fq6h-4g8v-qqvm
Patch:          CVE-2024-24815.patch
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pillow
Requires:       python-django-js-asset >= 2.0
BuildArch:      noarch
%python_subpackages

%description
Django admin CKEditor integration. Provides a RichTextField and
CKEditorWidget utilizing CKEditor with image upload and browsing
support included.

%prep
%autosetup -p1 -n django_ckeditor-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# tests need to be online and require web browser

%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst README.rst
%license LICENSE
%{python_sitelib}/ckeditor*
%{python_sitelib}/django_ckeditor-%{version}*info

%changelog
* Thu Dec  5 2024 Markéta Machová <mmachova@suse.com>
- Update to 6.7.2
  * Deprecated the package.
  * Added a new ckeditor/fixups.js script which disables the version check again
    (if something slips through by accident) and which disables the behavior
    where CKEditor 4 would automatically attach itself to unrelated HTML elements
    with a contenteditable attribute (see CKEDITOR.disableAutoInline in the
    CKEditor 4 docs).
- Add CVE-2024-24815.patch (bsc#1219720, CVE-2024-24815)
* Thu Mar 28 2024 Max Lin <mlin@suse.com>
- Add %%{?sle15_python_module_pythons}
* Thu Feb  8 2024 Dirk Müller <dmueller@suse.com>
- update to 6.7.1:
  * Add Python 3.12, Django 5.0
  * Silence the CKEditor version check/nag but include a system
    check warning
* Tue Nov 14 2023 Dirk Müller <dmueller@suse.com>
- update to 6.7.0:
  * Dark mode fixes.
  * Added support for Pillow 10.
* Sat Jul  1 2023 Dirk Müller <dmueller@suse.com>
- update to 6.6.1:
  * Required a newer version of django-js-asset which actually works
    with Django 4.1.
  * CKEditor 4.21.0
  * Fixed the CKEditor styles when used with the dark Django admin theme.
* Fri Jan 13 2023 Dirk Müller <dmueller@suse.com>
- update to 6.5.1:
  * Avoided calling ``static()`` if ``CKEDITOR_BASEPATH`` is defined.
  * Fixed ``./manage.py generateckeditorthumbnails`` to work again after the
    image uploader backend rework.
  * CKEditor 4.19.1
  * Stopped calling ``static()`` during application startup.
  * Added Django 4.1
  * Changed the context for the widget to deviate less from Django. Removed a
  * few template variables which are not used in the bundled
  * ``ckeditor/widget.html`` template. This only affects you if you are using a
  * customized widget or widget template.
  * Dropped support for Python < 3.8, Django < 3.2.
  * Added a pre-commit configuration.
  * Added a GitHub action for running tests.
  * Made selenium tests require opt in using a ``SELENIUM=firefox`` or
    ``SELENIUM=chromium`` environment variable.
  * Made it possible to override the CKEditor template in the widget class.
  * Changed ``CKEDITOR_IMAGE_BACKEND`` to require dotted module paths (the old
    identifiers are still supported for now).
* Sun Nov 29 2020 ecsos <ecsos@opensuse.org>
- Update to 6.0.0:
  * ckeditor update
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.9.0:
  * ckeditor update
* Tue Jan  7 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.8.0:
  * CKEditor 4.13
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 5.7.1:
  * Documentation improvements
  * Allow non-string properties of user for CKEDITOR_RESTRICT_BY_USER
  * Django 2.1 compatibility, minimal supported Django version is 1.11 LTS
  * Option to set custom django file backend for CKEditor uploader app.
  * Fix Django 1.8 - 1.10 regression
  * Drop leftover support for Django older than 1.8
  * Django 2.2 support
  * Minor fixes to JS handling
  * CKEditor 4.11.4
  * Allow using settings to configure extra_plugins and external_plugin_resources
* Sat May  4 2019 Martin Herkt <9+suse@cirno.systems>
- Revive package, update to 5.4.0
  * Django 2.0 compatibility
  5.3.1
  * Actually include the code which sets ``CKEDITOR_BASEPATH``.
  * CKEditor 4.7.3
  5.3.0
  * CKEditor 4.7
  * Fix storage problems by setting ``CKEDITOR_BASEPATH``
    (hopefully for real this time)
  * Documentation updates
  * Added a ``CKEDITOR_RESTRICT_BY_DATE`` setting to add uploaded
    files into folders containing the current date.
  * Added a ``CKEDITOR_FILEICONS`` setting that allows overriding
    the icons used by Gallerific.
  * Added a ``CKEDITOR_FILENAME_GENERATOR`` setting which allows
    specifying a callable which mangles the filename of uploaded
    files.
  * Added ``THUMBNAIL_SIZE`` and ``IMAGE_QUALITY`` settings for the
    Pillow image backend.
  * Actually include static assets for ``ckeditor_uploader`` in the
    pip-installable package.
  * Removed ``CKEDITOR_JQUERY_URL`` and the jQuery dependency.
    The CKEditor activation now uses plain JavaScript.
    Dependencies are JSON.parse and document.querySelectorAll which
    are supported in practically all used browsers these days.
  * Fixed a bug where the CKEditor language was not set
    individually for each request.
  5.2.2
  * Django 1.11 support
  * Drop South migrations
  * Fix storage problems by setting CKEDITOR_BASEPATH
  5.2.1
  * Fix CKEditor package static path
  5.2.0
  * Django 1.10 updates
  * Development dependencies bump
  * CKEditor 4.6.1
  * Paste image support
  * Fix for ManifestStaticFilesStorage
  5.1.1
  * Re-add missing additional CkEditor plugins
  5.1.0
  * Updated CkEditor to 4.5.10
  * Django 1.10 compatibility changes
  * Documentation updates
  5.0.3
  * Fix file/directory browsing and searching
  * Editor width style fixes
  * Added CKEDITOR_BROWSE_SHOW_DIRS
  * Added CKEDITOR_ALLOW_NONIMAGE_FILES
  * Python 2.6 compatibility fix
  5.0.2
  * Added template missing in the package
  5.0.1
  * Update Readme with backward-incompatible changes
  5.0.0 (4.5.3)
  * Moved file upload code to new Django application -
    ckeditor_uploader. `RichTextField` doesn't use file upload
    which have been moved to `RichTextUploadingField`.
    File upload support have been moved to ckeditor_uploader.
    The urls are in ckeditor_uploader.urls while for file uploading
    widget you have to use RichTextUploadingField from
    ckeditor_uploader.fields instead of RichTextField from
    from ckeditor.fields.
  * Updated ckeditor to 4.5.3
  * Added new plugins from ckeditor maintainers: adobeair, ajax,
    autoembed, autogrow, autolink, bbcode, codesnippet,
    codesnippetgeshi, devtools, divarea, docprops, embed,
    embedbase, embedsemantic, filetools, iframedialog, image2,
    language, lineutils, mathjax, menubutton, notification,
    notificationaggregator, placeholder, sharedspace, sourcedialog,
    stylesheetparser, tableresize, uicolor, uploadimage,
    uploadwidget, widget, xml
  * Add code quality configurations
  * Add EditorConfig configuration file
  * Refactored code to be in compliance with PEP8
  4.5.1
  * Fixed unbound variable in non-image file upload
  4.5.0
  * Updated ckeditor to 4.5.1
  * Reverted
    django.contrib.staticfiles.templatetags.staticfiles.static
    usage causing problems with some storages
  * Allow non-image files to be upload (the upload widget expects
    images so the user experience isn't best at the moment)
  * Few refactors and fixes to selenium tests
  4.4.8
  * Python 3 compatibility fixes
  * Get static files paths in a proper way
  * Fix Django 1.7 deprecation warning
  * More examples in readme
  4.4.7
  * Allow only POST requests on upload view.
  * Exclude hidden files from image browser
  * Prevent caching of image browser view
  * Use lazy JSON encoder to support i18n in CKEditor settings.
  * Misc documentation updates
  * Check for jQuery presence correctly
  * Update to CKEditor 4.4.6
  4.4.6
  * Make upload/browse views be staff_member_required by default
    (can be overridden)
  * Fix ckeditor initialisation code breaking with other jQuery
    versions.
  * Support grappelli inline form widgets.
  * Remove odd left margin from widget template.
  * Allow running selenium tests with chromium.
  4.4.5
  * Post merge package name fix in Readme
  4.4.4
  * Update CKEditor to 4.4.4 full package - for all plugins and
    static files you may need
  * Fixes for inline editor
  * Editor initialisation uses jQuery. You need to specify
    CKEDITOR_JQUERY_URL for it to work.
  4.4.0
  * Update CKEditor to 4.4.1
  * Django 1.7 compatibility fix
  4.2.8
  * Update CKEditor to 4.3.3
  4.2.7
  * Fix slugifying to empty filename if only bad characters given
    in filename. Use random string as fallback.
  * Don't use IMG tags for non image files in ckeditor file browser
  * Remove non-existing image reference from CSS files that broke
    collectstatic.
  * Misc fixes
  4.2.5 / 4.2.6
  * Fix static files installation - switch from distutils to
    setuptools
  4.2.4
  * Added new demo application with selenium integration test
  * tox setup for Python 3.3 and 2.7 testing
  * Extracted image processing to backends.
    PIL/Pillow is optional now. Other backends can be added.
  * Fixed a bug with thumbnail generation
  4.2.3
  * Python 3.3 compatibility
  * All uploaded files are slugified by default
    (New settings CKEDITOR_SLUGIFY_FILENAME)
  * Upload file when editing a link (<a href>) now works properly
  4.2.2
  * Python 3.3 compatibility in widgets.py
  4.2.1
  * Include CKEditor version 4.2.1.
  * Support Django 1.6
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 4.0.2
  + Include CKEditor version 4.0.2
- Add documentation from tarball
- Use source url as source
- Replace python-distribute with python-setuptools BuildRequires
* Sun Apr 22 2012 alexandre@exatati.com.br
- Update to 3.6.2:
  - Include CKEditor version 3.6.2.
  - Initial work on Django aligned theme.
  - Fix schema slash removal issue on media url generation.
    Thanks mwcz <https://github.com/mwcz>
  - Added compatibility for South. Thanks `3point2
    <https://github.com/3point2>`
  - Prevented settings from leaking between widget instances.
    Thanks `3point2 <https://github.com/3point2>`
  - Fixed config_name conflict when verbose_name is used as first
    positional argument for a field. Thanks `3point2
    <https://github.com/3point2>`
  - Refactored views to allow use of file walking with local paths.
    Thanks `3point2 <https://github.com/3point2>`_
  - Added command to generate thumbnails. Thanks `3point2
    <https://github.com/3point2>`
  - Migrated from using media to static file management.
- Reworked spec file.
* Thu Dec  9 2010 alexandre@exatati.com.br
- Update to 0.0.9.
* Wed Oct 13 2010 alexandre@exatati.com.br
- Update to 0.0.8.
* Wed Oct 13 2010 alexandre@exatati.com.br
- Update to 0.0.7.
* Sun Oct 10 2010 alexandre@exatati.com.br
- Update to 0.0.6;
- Bzip2 source file.
* Tue Jun 29 2010 alexandre@exatati.com.br
- Update to 0.0.5.
* Wed Jun 23 2010 alexandre@exatati.com.br
- Update to 0.0.4.
* Sun May 30 2010 alexandre@exatati.com.br
- Update to 0.0.2.
* Sat May 29 2010 alexandre@exatati.com.br
- Initial package (0.0.1) for openSUSE.
